# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import re  # noqa: F401
import sys  # noqa: F401
import typing  # noqa: F401
import functools  # noqa: F401

from frozendict import frozendict  # noqa: F401

import decimal  # noqa: F401
from datetime import date, datetime  # noqa: F401
from frozendict import frozendict  # noqa: F401

from ehelply_python_experimental_sdk.schemas import (  # noqa: F401
    AnyTypeSchema,
    ComposedSchema,
    DictSchema,
    ListSchema,
    StrSchema,
    IntSchema,
    Int32Schema,
    Int64Schema,
    Float32Schema,
    Float64Schema,
    NumberSchema,
    UUIDSchema,
    DateSchema,
    DateTimeSchema,
    DecimalSchema,
    BoolSchema,
    BinarySchema,
    NoneSchema,
    none_type,
    Configuration,
    Unset,
    unset,
    ComposedBase,
    ListBase,
    DictBase,
    NoneBase,
    StrBase,
    IntBase,
    Int32Base,
    Int64Base,
    Float32Base,
    Float64Base,
    NumberBase,
    UUIDBase,
    DateBase,
    DateTimeBase,
    BoolBase,
    BinaryBase,
    Schema,
    _SchemaValidator,
    _SchemaTypeChecker,
    _SchemaEnumMaker
)


class PaymentMethodResponse(
    DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    _required_property_names = set((
        'payment_id',
        'last_4_digits',
        'card_brand',
        'project_uuid',
    ))
    payment_id = StrSchema
    last_4_digits = StrSchema
    card_brand = StrSchema
    project_uuid = StrSchema


    def __new__(
        cls,
        *args: typing.Union[dict, frozendict, ],
        payment_id: payment_id,
        last_4_digits: last_4_digits,
        card_brand: card_brand,
        project_uuid: project_uuid,
        _configuration: typing.Optional[Configuration] = None,
        **kwargs: typing.Type[Schema],
    ) -> 'PaymentMethodResponse':
        return super().__new__(
            cls,
            *args,
            payment_id=payment_id,
            last_4_digits=last_4_digits,
            card_brand=card_brand,
            project_uuid=project_uuid,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.users_api import UsersApi  # noqa: E501


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_confirm_signup(self):
        """Test case for confirm_signup

        Confirmsignup  # noqa: E501
        """
        pass

    def test_create_participant(self):
        """Test case for create_participant

        Createparticipant  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Createuser  # noqa: E501
        """
        pass

    def test_delete_participant(self):
        """Test case for delete_participant

        Deleteparticipant  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Deleteuser  # noqa: E501
        """
        pass

    def test_get_participant(self):
        """Test case for get_participant

        Getparticipant  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Getuser  # noqa: E501
        """
        pass

    def test_login(self):
        """Test case for login

        Login  # noqa: E501
        """
        pass

    def test_refresh_token(self):
        """Test case for refresh_token

        Refreshtoken  # noqa: E501
        """
        pass

    def test_reset_password(self):
        """Test case for reset_password

        Resetpassword  # noqa: E501
        """
        pass

    def test_reset_password_confirmation(self):
        """Test case for reset_password_confirmation

        Resetpasswordconfirmation  # noqa: E501
        """
        pass

    def test_search_participants(self):
        """Test case for search_participants

        Searchparticipants  # noqa: E501
        """
        pass

    def test_signup(self):
        """Test case for signup

        Signup  # noqa: E501
        """
        pass

    def test_update_participant(self):
        """Test case for update_participant

        Updateparticipant  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Updateuser  # noqa: E501
        """
        pass

    def test_user_validations(self):
        """Test case for user_validations

        Uservalidations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.meta_api_endpoints.create_field import CreateField
from ehelply_python_experimental_sdk.api.meta_api_endpoints.create_meta import CreateMeta
from ehelply_python_experimental_sdk.api.meta_api_endpoints.delete_field import DeleteField
from ehelply_python_experimental_sdk.api.meta_api_endpoints.delete_meta import DeleteMeta
from ehelply_python_experimental_sdk.api.meta_api_endpoints.delete_meta_from_uuid import DeleteMetaFromUuid
from ehelply_python_experimental_sdk.api.meta_api_endpoints.get_field import GetField
from ehelply_python_experimental_sdk.api.meta_api_endpoints.get_meta import GetMeta
from ehelply_python_experimental_sdk.api.meta_api_endpoints.get_meta_from_uuid import GetMetaFromUuid
from ehelply_python_experimental_sdk.api.meta_api_endpoints.make_slug import MakeSlug
from ehelply_python_experimental_sdk.api.meta_api_endpoints.touch_meta import TouchMeta
from ehelply_python_experimental_sdk.api.meta_api_endpoints.update_field import UpdateField
from ehelply_python_experimental_sdk.api.meta_api_endpoints.update_meta import UpdateMeta
from ehelply_python_experimental_sdk.api.meta_api_endpoints.update_meta_from_uuid import UpdateMetaFromUuid


class MetaApi(
    CreateField,
    CreateMeta,
    DeleteField,
    DeleteMeta,
    DeleteMetaFromUuid,
    GetField,
    GetMeta,
    GetMetaFromUuid,
    MakeSlug,
    TouchMeta,
    UpdateField,
    UpdateMeta,
    UpdateMetaFromUuid,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.monitor_api import MonitorApi  # noqa: E501


class TestMonitorApi(unittest.TestCase):
    """MonitorApi unit test stubs"""

    def setUp(self):
        self.api = MonitorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_acknowledge_alarm(self):
        """Test case for acknowledge_alarm

        Acknowledgealarm  # noqa: E501
        """
        pass

    def test_assign_alarm(self):
        """Test case for assign_alarm

        Assignalarm  # noqa: E501
        """
        pass

    def test_attach_alarm_note(self):
        """Test case for attach_alarm_note

        Attachalarmnote  # noqa: E501
        """
        pass

    def test_attach_alarm_ticket(self):
        """Test case for attach_alarm_ticket

        Attachalarmticket  # noqa: E501
        """
        pass

    def test_clear_alarm(self):
        """Test case for clear_alarm

        Clearalarm  # noqa: E501
        """
        pass

    def test_get_service(self):
        """Test case for get_service

        Getservice  # noqa: E501
        """
        pass

    def test_get_service_alarm(self):
        """Test case for get_service_alarm

        Getservicealarm  # noqa: E501
        """
        pass

    def test_get_service_alarms(self):
        """Test case for get_service_alarms

        Getservicealarms  # noqa: E501
        """
        pass

    def test_get_service_heartbeat(self):
        """Test case for get_service_heartbeat

        Getserviceheartbeat  # noqa: E501
        """
        pass

    def test_get_service_kpis(self):
        """Test case for get_service_kpis

        Getservicekpis  # noqa: E501
        """
        pass

    def test_get_service_spec(self):
        """Test case for get_service_spec

        Getservicespec  # noqa: E501
        """
        pass

    def test_get_service_specs(self):
        """Test case for get_service_specs

        Getservicespecs  # noqa: E501
        """
        pass

    def test_get_service_vitals(self):
        """Test case for get_service_vitals

        Getservicevitals  # noqa: E501
        """
        pass

    def test_get_services(self):
        """Test case for get_services

        Getservices  # noqa: E501
        """
        pass

    def test_get_services_with_specs(self):
        """Test case for get_services_with_specs

        Getserviceswithspecs  # noqa: E501
        """
        pass

    def test_hide_service(self):
        """Test case for hide_service

        Hideservice  # noqa: E501
        """
        pass

    def test_ignore_alarm(self):
        """Test case for ignore_alarm

        Ignorealarm  # noqa: E501
        """
        pass

    def test_register_service(self):
        """Test case for register_service

        Registerservice  # noqa: E501
        """
        pass

    def test_search_alarms(self):
        """Test case for search_alarms

        Searchalarms  # noqa: E501
        """
        pass

    def test_show_service(self):
        """Test case for show_service

        Showservice  # noqa: E501
        """
        pass

    def test_terminate_alarm(self):
        """Test case for terminate_alarm

        Terminatealarm  # noqa: E501
        """
        pass

    def test_trigger_alarm(self):
        """Test case for trigger_alarm

        Triggeralarm  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import re  # noqa: F401
import sys  # noqa: F401
import typing  # noqa: F401
import functools  # noqa: F401

from frozendict import frozendict  # noqa: F401

import decimal  # noqa: F401
from datetime import date, datetime  # noqa: F401
from frozendict import frozendict  # noqa: F401

from ehelply_python_experimental_sdk.schemas import (  # noqa: F401
    AnyTypeSchema,
    ComposedSchema,
    DictSchema,
    ListSchema,
    StrSchema,
    IntSchema,
    Int32Schema,
    Int64Schema,
    Float32Schema,
    Float64Schema,
    NumberSchema,
    UUIDSchema,
    DateSchema,
    DateTimeSchema,
    DecimalSchema,
    BoolSchema,
    BinarySchema,
    NoneSchema,
    none_type,
    Configuration,
    Unset,
    unset,
    ComposedBase,
    ListBase,
    DictBase,
    NoneBase,
    StrBase,
    IntBase,
    Int32Base,
    Int64Base,
    Float32Base,
    Float64Base,
    NumberBase,
    UUIDBase,
    DateBase,
    DateTimeBase,
    BoolBase,
    BinaryBase,
    Schema,
    _SchemaValidator,
    _SchemaTypeChecker,
    _SchemaEnumMaker
)


class UserSignup(
    DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    User information used for user signup
    """
    _required_property_names = set((
        'username',
        'password',
        'email',
        'first_name',
        'last_name',
        'phone_number',
        'country',
    ))
    username = StrSchema
    password = StrSchema
    email = StrSchema
    first_name = StrSchema
    last_name = StrSchema
    phone_number = StrSchema
    country = StrSchema
    lat = StrSchema
    lng = StrSchema
    verified_legal_terms = BoolSchema
    picture = StrSchema
    newsletters = BoolSchema


    def __new__(
        cls,
        *args: typing.Union[dict, frozendict, ],
        username: username,
        password: password,
        email: email,
        first_name: first_name,
        last_name: last_name,
        phone_number: phone_number,
        country: country,
        lat: typing.Union[lat, Unset] = unset,
        lng: typing.Union[lng, Unset] = unset,
        verified_legal_terms: typing.Union[verified_legal_terms, Unset] = unset,
        picture: typing.Union[picture, Unset] = unset,
        newsletters: typing.Union[newsletters, Unset] = unset,
        _configuration: typing.Optional[Configuration] = None,
        **kwargs: typing.Type[Schema],
    ) -> 'UserSignup':
        return super().__new__(
            cls,
            *args,
            username=username,
            password=password,
            email=email,
            first_name=first_name,
            last_name=last_name,
            phone_number=phone_number,
            country=country,
            lat=lat,
            lng=lng,
            verified_legal_terms=verified_legal_terms,
            picture=picture,
            newsletters=newsletters,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.projects_api_endpoints.add_member_to_project import AddMemberToProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.archive_project import ArchiveProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_project import CreateProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_project_key import CreateProjectKey
from ehelply_python_experimental_sdk.api.projects_api_endpoints.create_usage_type import CreateUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.delete_project_key import DeleteProjectKey
from ehelply_python_experimental_sdk.api.projects_api_endpoints.delete_usage_type import DeleteUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_all_project_usage import GetAllProjectUsage
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_member_projects import GetMemberProjects
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project import GetProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project_keys import GetProjectKeys
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_project_members import GetProjectMembers
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_specific_project_usage import GetSpecificProjectUsage
from ehelply_python_experimental_sdk.api.projects_api_endpoints.get_usage_type import GetUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.remove_member_from_project import RemoveMemberFromProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.search_projects import SearchProjects
from ehelply_python_experimental_sdk.api.projects_api_endpoints.search_usage_type import SearchUsageType
from ehelply_python_experimental_sdk.api.projects_api_endpoints.update_project import UpdateProject
from ehelply_python_experimental_sdk.api.projects_api_endpoints.update_usage_type import UpdateUsageType


class ProjectsApi(
    AddMemberToProject,
    ArchiveProject,
    CreateProject,
    CreateProjectKey,
    CreateUsageType,
    DeleteProjectKey,
    DeleteUsageType,
    GetAllProjectUsage,
    GetMemberProjects,
    GetProject,
    GetProjectKeys,
    GetProjectMembers,
    GetSpecificProjectUsage,
    GetUsageType,
    RemoveMemberFromProject,
    SearchProjects,
    SearchUsageType,
    UpdateProject,
    UpdateUsageType,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.staff_api import StaffApi  # noqa: E501


class TestStaffApi(unittest.TestCase):
    """StaffApi unit test stubs"""

    def setUp(self):
        self.api = StaffApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_staff_places_staff_post(self):
        """Test case for create_staff_places_staff_post

        Create Staff  # noqa: E501
        """
        pass

    def test_delete_staff_places_staff_staff_uuid_delete(self):
        """Test case for delete_staff_places_staff_staff_uuid_delete

        Delete Staff  # noqa: E501
        """
        pass

    def test_get_staff_places_staff_staff_uuid_get(self):
        """Test case for get_staff_places_staff_staff_uuid_get

        Get Staff  # noqa: E501
        """
        pass

    def test_search_staff_places_staff_get(self):
        """Test case for search_staff_places_staff_get

        Search Staff  # noqa: E501
        """
        pass

    def test_update_staff_places_staff_staff_uuid_put(self):
        """Test case for update_staff_places_staff_staff_uuid_put

        Update Staff  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from ehelply_python_experimental_sdk.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from ehelply_python_experimental_sdk.model.address_base import AddressBase
from ehelply_python_experimental_sdk.model.alarm_acknowledge import AlarmAcknowledge
from ehelply_python_experimental_sdk.model.alarm_assign import AlarmAssign
from ehelply_python_experimental_sdk.model.alarm_create import AlarmCreate
from ehelply_python_experimental_sdk.model.alarm_ignore import AlarmIgnore
from ehelply_python_experimental_sdk.model.alarm_note import AlarmNote
from ehelply_python_experimental_sdk.model.alarm_response import AlarmResponse
from ehelply_python_experimental_sdk.model.alarm_terminate import AlarmTerminate
from ehelply_python_experimental_sdk.model.alarm_ticket import AlarmTicket
from ehelply_python_experimental_sdk.model.appointment_base import AppointmentBase
from ehelply_python_experimental_sdk.model.appointment_response import AppointmentResponse
from ehelply_python_experimental_sdk.model.attach_payment_to_project import AttachPaymentToProject
from ehelply_python_experimental_sdk.model.basic_meta import BasicMeta
from ehelply_python_experimental_sdk.model.basic_meta_create import BasicMetaCreate
from ehelply_python_experimental_sdk.model.catalog_base import CatalogBase
from ehelply_python_experimental_sdk.model.catalog_return import CatalogReturn
from ehelply_python_experimental_sdk.model.category_base import CategoryBase
from ehelply_python_experimental_sdk.model.category_db import CategoryDb
from ehelply_python_experimental_sdk.model.company_base import CompanyBase
from ehelply_python_experimental_sdk.model.company_response import CompanyResponse
from ehelply_python_experimental_sdk.model.contact import Contact
from ehelply_python_experimental_sdk.model.contact_base import ContactBase
from ehelply_python_experimental_sdk.model.contact_method import ContactMethod
from ehelply_python_experimental_sdk.model.contact_response import ContactResponse
from ehelply_python_experimental_sdk.model.create_key_response import CreateKeyResponse
from ehelply_python_experimental_sdk.model.create_review import CreateReview
from ehelply_python_experimental_sdk.model.create_ticket import CreateTicket
from ehelply_python_experimental_sdk.model.custom_list import CustomList
from ehelply_python_experimental_sdk.model.dates_meta import DatesMeta
from ehelply_python_experimental_sdk.model.detailed_meta import DetailedMeta
from ehelply_python_experimental_sdk.model.detailed_meta_create import DetailedMetaCreate
from ehelply_python_experimental_sdk.model.field import Field
from ehelply_python_experimental_sdk.model.field_dynamo import FieldDynamo
from ehelply_python_experimental_sdk.model.get_service_service_with_specs_response import GetServiceServiceWithSpecsResponse
from ehelply_python_experimental_sdk.model.get_service_spec_response import GetServiceSpecResponse
from ehelply_python_experimental_sdk.model.get_service_specs_response import GetServiceSpecsResponse
from ehelply_python_experimental_sdk.model.http_validation_error import HTTPValidationError
from ehelply_python_experimental_sdk.model.heartbeat_response import HeartbeatResponse
from ehelply_python_experimental_sdk.model.kpi_response import KpiResponse
from ehelply_python_experimental_sdk.model.logging_dynamo import LoggingDynamo
from ehelply_python_experimental_sdk.model.meta_children import MetaChildren
from ehelply_python_experimental_sdk.model.meta_create import MetaCreate
from ehelply_python_experimental_sdk.model.meta_custom import MetaCustom
from ehelply_python_experimental_sdk.model.meta_dynamo import MetaDynamo
from ehelply_python_experimental_sdk.model.meta_slugger import MetaSlugger
from ehelply_python_experimental_sdk.model.note_base import NoteBase
from ehelply_python_experimental_sdk.model.note_dynamo_history_response import NoteDynamoHistoryResponse
from ehelply_python_experimental_sdk.model.note_dynamo_response import NoteDynamoResponse
from ehelply_python_experimental_sdk.model.note_meta import NoteMeta
from ehelply_python_experimental_sdk.model.option_group import OptionGroup
from ehelply_python_experimental_sdk.model.options import Options
from ehelply_python_experimental_sdk.model.page import Page
from ehelply_python_experimental_sdk.model.pagination import Pagination
from ehelply_python_experimental_sdk.model.participant_create import ParticipantCreate
from ehelply_python_experimental_sdk.model.participant_update import ParticipantUpdate
from ehelply_python_experimental_sdk.model.participant_user_return import ParticipantUserReturn
from ehelply_python_experimental_sdk.model.payment import Payment
from ehelply_python_experimental_sdk.model.payment_method_response import PaymentMethodResponse
from ehelply_python_experimental_sdk.model.place_base import PlaceBase
from ehelply_python_experimental_sdk.model.place_response import PlaceResponse
from ehelply_python_experimental_sdk.model.product_base import ProductBase
from ehelply_python_experimental_sdk.model.product_return import ProductReturn
from ehelply_python_experimental_sdk.model.project_db import ProjectDB
from ehelply_python_experimental_sdk.model.projects_project_create import ProjectsProjectCreate
from ehelply_python_experimental_sdk.model.projects_project_get import ProjectsProjectGet
from ehelply_python_experimental_sdk.model.projects_project_member_db import ProjectsProjectMemberDB
from ehelply_python_experimental_sdk.model.projects_project_update import ProjectsProjectUpdate
from ehelply_python_experimental_sdk.model.projects_project_usage_db import ProjectsProjectUsageDB
from ehelply_python_experimental_sdk.model.projects_usage_type_create import ProjectsUsageTypeCreate
from ehelply_python_experimental_sdk.model.projects_usage_type_db import ProjectsUsageTypeDB
from ehelply_python_experimental_sdk.model.projects_usage_type_get import ProjectsUsageTypeGet
from ehelply_python_experimental_sdk.model.projects_usage_type_unit_price import ProjectsUsageTypeUnitPrice
from ehelply_python_experimental_sdk.model.projects_usage_type_update import ProjectsUsageTypeUpdate
from ehelply_python_experimental_sdk.model.security_create_token import SecurityCreateToken
from ehelply_python_experimental_sdk.model.security_encryption_key_get import SecurityEncryptionKeyGet
from ehelply_python_experimental_sdk.model.security_encryption_key_response import SecurityEncryptionKeyResponse
from ehelply_python_experimental_sdk.model.security_key_create import SecurityKeyCreate
from ehelply_python_experimental_sdk.model.security_key_get import SecurityKeyGet
from ehelply_python_experimental_sdk.model.security_key_verify import SecurityKeyVerify
from ehelply_python_experimental_sdk.model.selection import Selection
from ehelply_python_experimental_sdk.model.service_create import ServiceCreate
from ehelply_python_experimental_sdk.model.service_message_response import ServiceMessageResponse
from ehelply_python_experimental_sdk.model.service_response import ServiceResponse
from ehelply_python_experimental_sdk.model.staff_create import StaffCreate
from ehelply_python_experimental_sdk.model.staff_db import StaffDb
from ehelply_python_experimental_sdk.model.staff_response import StaffResponse
from ehelply_python_experimental_sdk.model.stats_vitals_response import StatsVitalsResponse
from ehelply_python_experimental_sdk.model.stripe_account_response import StripeAccountResponse
from ehelply_python_experimental_sdk.model.stripe_customer_secret_response import StripeCustomerSecretResponse
from ehelply_python_experimental_sdk.model.tag_base import TagBase
from ehelply_python_experimental_sdk.model.tag_db import TagDb
from ehelply_python_experimental_sdk.model.ticket_response import TicketResponse
from ehelply_python_experimental_sdk.model.tickets_response import TicketsResponse
from ehelply_python_experimental_sdk.model.update_review import UpdateReview
from ehelply_python_experimental_sdk.model.user import User
from ehelply_python_experimental_sdk.model.user_confirmation import UserConfirmation
from ehelply_python_experimental_sdk.model.user_email import UserEmail
from ehelply_python_experimental_sdk.model.user_flags import UserFlags
from ehelply_python_experimental_sdk.model.user_login import UserLogin
from ehelply_python_experimental_sdk.model.user_login_return import UserLoginReturn
from ehelply_python_experimental_sdk.model.user_password_reset import UserPasswordReset
from ehelply_python_experimental_sdk.model.user_password_reset_confirmation import UserPasswordResetConfirmation
from ehelply_python_experimental_sdk.model.user_response import UserResponse
from ehelply_python_experimental_sdk.model.user_signup import UserSignup
from ehelply_python_experimental_sdk.model.user_signup_return import UserSignupReturn
from ehelply_python_experimental_sdk.model.user_token_return import UserTokenReturn
from ehelply_python_experimental_sdk.model.user_validations import UserValidations
from ehelply_python_experimental_sdk.model.validation_error import ValidationError
from ehelply_python_experimental_sdk.model.validations import Validations



# coding: utf-8

# flake8: noqa

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.1.94"

# import ApiClient
from ehelply_python_experimental_sdk.api_client import ApiClient

# import Configuration
from ehelply_python_experimental_sdk.configuration import Configuration

# import exceptions
from ehelply_python_experimental_sdk.exceptions import OpenApiException
from ehelply_python_experimental_sdk.exceptions import ApiAttributeError
from ehelply_python_experimental_sdk.exceptions import ApiTypeError
from ehelply_python_experimental_sdk.exceptions import ApiValueError
from ehelply_python_experimental_sdk.exceptions import ApiKeyError
from ehelply_python_experimental_sdk.exceptions import ApiException



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "ehelply-python-experimental-sdk"
VERSION = "1.1.94"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.15",
  "certifi",
  "python-dateutil",
  "frozendict >= 2.0.3",
]

setup(
    name=NAME,
    version=VERSION,
    description="eHelply SDK - 1.1.94",
    author="Support",
    author_email="support@ehelply.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "eHelply SDK - 1.1.94"],
    python_requires=">=3.9",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache 2.0",
    long_description="""\
    eHelply SDK for SuperStack Services  # noqa: E501
    """
)



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import re  # noqa: F401
import sys  # noqa: F401
import typing  # noqa: F401
import functools  # noqa: F401

from frozendict import frozendict  # noqa: F401

import decimal  # noqa: F401
from datetime import date, datetime  # noqa: F401
from frozendict import frozendict  # noqa: F401

from ehelply_python_experimental_sdk.schemas import (  # noqa: F401
    AnyTypeSchema,
    ComposedSchema,
    DictSchema,
    ListSchema,
    StrSchema,
    IntSchema,
    Int32Schema,
    Int64Schema,
    Float32Schema,
    Float64Schema,
    NumberSchema,
    UUIDSchema,
    DateSchema,
    DateTimeSchema,
    DecimalSchema,
    BoolSchema,
    BinarySchema,
    NoneSchema,
    none_type,
    Configuration,
    Unset,
    unset,
    ComposedBase,
    ListBase,
    DictBase,
    NoneBase,
    StrBase,
    IntBase,
    Int32Base,
    Int64Base,
    Float32Base,
    Float64Base,
    NumberBase,
    UUIDBase,
    DateBase,
    DateTimeBase,
    BoolBase,
    BinaryBase,
    Schema,
    _SchemaValidator,
    _SchemaTypeChecker,
    _SchemaEnumMaker
)


class AppointmentBase(
    DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    project_uuid = StrSchema
    place_uuid = StrSchema
    review_group_uuid = StrSchema
    expected_finish_at = StrSchema
    expected_start_at = StrSchema
    actual_start_at = StrSchema
    actual_finish_at = StrSchema
    products = DictSchema
    meta_uuid = StrSchema
    status = StrSchema
    cancellation_at = StrSchema
    cancellation_reason = StrSchema
    cancellation_entity_uuid = StrSchema


    def __new__(
        cls,
        *args: typing.Union[dict, frozendict, ],
        project_uuid: typing.Union[project_uuid, Unset] = unset,
        place_uuid: typing.Union[place_uuid, Unset] = unset,
        review_group_uuid: typing.Union[review_group_uuid, Unset] = unset,
        expected_finish_at: typing.Union[expected_finish_at, Unset] = unset,
        expected_start_at: typing.Union[expected_start_at, Unset] = unset,
        actual_start_at: typing.Union[actual_start_at, Unset] = unset,
        actual_finish_at: typing.Union[actual_finish_at, Unset] = unset,
        products: typing.Union[products, Unset] = unset,
        meta_uuid: typing.Union[meta_uuid, Unset] = unset,
        status: typing.Union[status, Unset] = unset,
        cancellation_at: typing.Union[cancellation_at, Unset] = unset,
        cancellation_reason: typing.Union[cancellation_reason, Unset] = unset,
        cancellation_entity_uuid: typing.Union[cancellation_entity_uuid, Unset] = unset,
        _configuration: typing.Optional[Configuration] = None,
        **kwargs: typing.Type[Schema],
    ) -> 'AppointmentBase':
        return super().__new__(
            cls,
            *args,
            project_uuid=project_uuid,
            place_uuid=place_uuid,
            review_group_uuid=review_group_uuid,
            expected_finish_at=expected_finish_at,
            expected_start_at=expected_start_at,
            actual_start_at=actual_start_at,
            actual_finish_at=actual_finish_at,
            products=products,
            meta_uuid=meta_uuid,
            status=status,
            cancellation_at=cancellation_at,
            cancellation_reason=cancellation_reason,
            cancellation_entity_uuid=cancellation_entity_uuid,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.support_api_endpoints.create_contact import CreateContact
from ehelply_python_experimental_sdk.api.support_api_endpoints.create_ticket import CreateTicket
from ehelply_python_experimental_sdk.api.support_api_endpoints.list_tickets import ListTickets
from ehelply_python_experimental_sdk.api.support_api_endpoints.update_ticket import UpdateTicket
from ehelply_python_experimental_sdk.api.support_api_endpoints.view_ticket import ViewTicket


class SupportApi(
    CreateContact,
    CreateTicket,
    ListTickets,
    UpdateTicket,
    ViewTicket,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.billing_api import BillingApi  # noqa: E501


class TestBillingApi(unittest.TestCase):
    """BillingApi unit test stubs"""

    def setUp(self):
        self.api = BillingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_billing_account(self):
        """Test case for create_billing_account

        Createbillingaccount  # noqa: E501
        """
        pass

    def test_get_client_secret(self):
        """Test case for get_client_secret

        Getclientsecret  # noqa: E501
        """
        pass

    def test_has_payment(self):
        """Test case for has_payment

        Haspayment  # noqa: E501
        """
        pass

    def test_list_payment_methods(self):
        """Test case for list_payment_methods

        Listpaymentmethods  # noqa: E501
        """
        pass

    def test_process_payment(self):
        """Test case for process_payment

        Processpayment  # noqa: E501
        """
        pass

    def test_reconcile_payment_method(self):
        """Test case for reconcile_payment_method

        Reconcilepaymentmethod  # noqa: E501
        """
        pass

    def test_remove_payment_method(self):
        """Test case for remove_payment_method

        Removepaymentmethod  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    eHelply SDK - 1.1.94

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.94
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.places_api import PlacesApi  # noqa: E501


class TestPlacesApi(unittest.TestCase):
    """PlacesApi unit test stubs"""

    def setUp(self):
        self.api = PlacesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_place_places_places_post(self):
        """Test case for create_place_places_places_post

        Create Place  # noqa: E501
        """
        pass

    def test_delete_place_places_places_place_uuid_delete(self):
        """Test case for delete_place_places_places_place_uuid_delete

        Delete Place  # noqa: E501
        """
        pass

    def test_forward_geocoding_places_geocoding_forward_get(self):
        """Test case for forward_geocoding_places_geocoding_forward_get

        Forward Geocoding  # noqa: E501
        """
        pass

    def test_get_place_places_places_place_uuid_get(self):
        """Test case for get_place_places_places_place_uuid_get

        Get Place  # noqa: E501
        """
        pass

    def test_reverse_geocoding_places_geocoding_reverse_get(self):
        """Test case for reverse_geocoding_places_geocoding_reverse_get

        Reverse Geocoding  # noqa: E501
        """
        pass

    def test_search_places_by_search_string_places_search_places_string_get(self):
        """Test case for search_places_by_search_string_places_search_places_string_get

        Search Places By Search String  # noqa: E501
        """
        pass

    def test_search_places_places_places_get(self):
        """Test case for search_places_places_places_get

        Search Places  # noqa: E501
        """
        pass

    def test_update_place_places_places_place_uuid_put(self):
        """Test case for update_place_places_places_place_uuid_put

        Update Place  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
